use argh::FromArgs;

use crate::action::ActionExec;
use crate::api::qbittorrent::ApiClient;
use crate::config::Config;
use crate::error::Error;

#[derive(FromArgs, Debug)]
#[argh(subcommand, name = "get-trackers")]
/// Get the list of trackers on a torrent
/// TODO: Also make list of all trackers?
pub struct GetTrackersAction {
    #[argh(switch, short = 'j')]
    /// return the list of trackers as a JSON object
    json: bool,
    #[argh(positional)]
    /// the torrent to fetch trackers from
    torrent: String,
}

impl ActionExec for GetTrackersAction {
    fn exec(&self, config: &Config) -> Result<(), Error> {
        let api = ApiClient::from_config(&config)?;
        let trackers = api.get_trackers(&self.torrent)?;

        if self.json {
            println!("{}", serde_json::to_string(&trackers).unwrap());
        } else {
            for entry in &trackers {
                println!("{}", &entry.url);
            }
        }
        Ok(())
    }
}
