use argh::FromArgs;

use crate::api::qbittorrent::ApiClient;
use crate::Error;
use crate::action::ActionExec;
use crate::config::Config;

#[derive(FromArgs, PartialEq, Debug)]
#[argh(subcommand, name = "list")]
/// list existing torrents on qBittorrent
pub struct ListAction {
    #[argh(switch, short = 'j')]
    /// return parsed JSON response from API
    json: bool,
}

impl ActionExec for ListAction {
    fn exec(&self, config: &Config) -> Result<(), Error> {
        let api = ApiClient::from_config(&config)?;
        for torrent in api.list()? {
            if self.json {
                println!("{}", &serde_json::to_string(&torrent).unwrap());
            } else {
                println!("{}", torrent.hash);
            }
        }

        Ok(())
    }
}
