use argh::FromArgs;

use crate::Error;
use crate::config::Config;

pub mod add;
pub use add::AddAction;
pub mod get;
pub use get::GetAction;
pub mod get_trackers;
pub use get_trackers::GetTrackersAction;
pub mod hash;
pub use hash::HashAction;
pub mod list;
pub use list::ListAction;
pub mod magnet;
pub use magnet::MagnetAction;
pub mod name;
pub use name::NameAction;
pub mod replace_tracker;
pub use replace_tracker::ReplaceTrackerAction;
pub mod replace_all_trackers;
pub use replace_all_trackers::ReplaceAllTrackersAction;

#[derive(FromArgs, Debug)]
#[argh(subcommand)]
pub enum Action {
    Add(AddAction),
    List(ListAction),
    Get(GetAction),
    GetTrackers(GetTrackersAction),
    Name(NameAction),
    Hash(HashAction),
    Magnet(MagnetAction),
    ReplaceTracker(ReplaceTrackerAction),
    ReplaceAllTrackers(ReplaceAllTrackersAction),
}

pub trait ActionExec {
    fn exec(&self, config: &Config) -> Result<(), Error>;
}

impl Action {
    pub fn exec(&self, config: &Config) -> Result<(), Error> {
        match self {
            Action::Add(cmd) => {
                cmd.exec(&config)
            }, Action::List(cmd) => {
                cmd.exec(&config)
            }, Action::Get(cmd) => {
                cmd.exec(&config)
            }, Action::GetTrackers(cmd) => {
                cmd.exec(&config)
            }, Action::Hash(cmd) => {
                cmd.exec(&config)
            }, Action::Name(cmd) => {
                cmd.exec(&config)
            }, Action::Magnet(cmd) => {
                cmd.exec(&config)
            }, Action::ReplaceTracker(cmd) => {
                cmd.exec(&config)
            }, Action::ReplaceAllTrackers(cmd) => {
                cmd.exec(&config)
            },
        }
 
    }
}
