use crate::api::{Torrent, IntoTorrent};

/// Deserializes from the 'properties' endpoint of QBittorrent API
/// https://github.com/qbittorrent/qBittorrent/wiki/WebUI-API-(qBittorrent-4.1)#get-torrent-generic-properties
#[derive(Clone, Deserialize)]
pub struct QBittorrentPropertiesTorrent {
    pub name: String,
    #[serde(rename="save_path")]
    pub path: String,
    #[serde(rename="addition_date")]
    pub date_start: i64,
    #[serde(rename="completion_date")]
    pub date_end: i64,
    #[serde(rename="pieces_have")]
    pub pieces_have: i64,
    #[serde(rename="pieces_num")]
    pub pieces_total: i64,
    #[serde(rename="total_size")]
    pub size: i64,
}

/// Deserializes from the 'info' endpoint of QBittorrent API
/// https://github.com/qbittorrent/qBittorrent/wiki/WebUI-API-(qBittorrent-4.1)#get-torrent-list
#[derive(Clone, Deserialize)]
pub struct QBittorrentListTorrent {
    pub hash: String,
    pub name: String,
    #[serde(rename="save_path")]
    pub path: String,
    #[serde(rename="added_on")]
    pub date_start: i64,
    #[serde(rename="completion_on")]
    pub date_end: i64,
    pub progress: f32,
    #[serde(rename="total_size")]
    pub size: i64,
}

impl IntoTorrent for QBittorrentListTorrent {
    fn into_torrent(&self) -> Torrent {
        Torrent {
            hash: self.hash.to_string(),
            name: self.name.to_string(),
            path: self.path.to_string(),
            date_start: self.date_start,
            date_end: self.date_end,
            progress: (self.progress * 100.0) as u8,
            size: self.size,
        }
    }
}
